=========
Changelog
=========

Version 0.1.1
=============

- Downgraded `microsoft-kiota-abstractions`, `microsoft-kiota-http` and `microsoft-kiota-serialization-json` to version `1.3.3` to allow installation in Home Assistant.
- Adjusted `pyproject.toml` and `requirements.txt` to reflect the changes.

Version 0.1
===========

- Initial release
